@@ -47,22 +47,22 @@ class ApiResult(object):
         self.http_code = None
         self.time = None
 
-        self.__data = None
+        self._data = None
 
     def process(self, response):
         try:
-            self.__data = json.loads(response, object_hook=from_dict)
+            self._data = json.loads(response, object_hook=from_dict)
         except ValueError, e:
             self.body = response
 
             raise errors.MalformedJSONResultError(self, e.message)
 
-        if self.__data.error.code:
-            raise get_result_error(self, self.__data.error)
+        if self._data.error.code:
+            raise get_result_error(self, self._data.error)
 
     @property
     def value(self):
-        return self.__data.result
+        return self._data.result
 
     def dump(self):
         return self.value
@@ -70,20 +70,20 @@ class ApiResult(object):
 
 class ApiClient(object):
     def __init__(self, api_id, secret_key):
-        self.__api_id = api_id
-        self.__secret_key = secret_key
+        self._api_id = api_id
+        self._secret_key = secret_key
 
         self.env = Environment()
 
-        self.__opener = urllib2.build_opener(
+        self._opener = urllib2.build_opener(
             handlers.UserAgentProcessor(floraconcierge.HTTP_CLIENT_UA),
             handlers.GZipProcessor()
         )
 
-        self.__api_endpoint = 'http://api.floraconcierge.com/v1/'
-        self.__debug = False
-        self.__calls = list()
-        self.__calls_time = timedelta()
+        self._api_endpoint = 'http://api.floraconcierge.com/v1/'
+        self._debug = False
+        self._calls = list()
+        self._calls_time = timedelta()
 
         # importing here avoid import recursion
         from floraconcierge.services import Manager
@@ -92,19 +92,19 @@ class ApiClient(object):
 
     @property
     def api_endpoint(self):
-        return self.__api_endpoint
+        return self._api_endpoint
 
     @api_endpoint.setter
     def api_endpoint(self, url):
-        self.__api_endpoint = url
+        self._api_endpoint = url
 
     @property
     def debug(self):
-        return self.__debug
+        return self._debug
 
     @debug.setter
     def debug(self, value):
-        self.__debug = bool(value)
+        self._debug = bool(value)
 
     @staticmethod
     def get_timestamp(time=None):
@@ -114,12 +114,12 @@ class ApiClient(object):
 
     @property
     def calls(self):
-        return self.__calls
+        return self._calls
 
     @calls.deleter
     def calls(self):
-        self.__calls = list()
-        self.__calls_time = timedelta()
+        self._calls = list()
+        self._calls_time = timedelta()
 
     def sign(self, **kwargs):
         sign = dict((k, v) for k, v in kwargs.iteritems() if k[0] != '_')
@@ -133,7 +133,7 @@ class ApiClient(object):
 
         tosign = "".join(tosign)
 
-        return hashlib.sha1("%s:%s" % (self.__secret_key, tosign)).hexdigest()
+        return hashlib.sha1("%s:%s" % (self._secret_key, tosign)).hexdigest()
 
     def call(self, func, get=None, post=None):
         get, post, start = get or dict(), post or dict(), datetime.now()
@@ -146,19 +146,19 @@ class ApiClient(object):
 
         get.update({
             '_sign': self.sign(**get),
-            '_api_id': self.__api_id,
+            '_api_id': self._api_id,
         })
         get.update(self.env.params)
 
         get = dict((k, v) for k, v in get.iteritems() if k[0] != '_' or v)
 
-        url = "%s%s?%s" % (self.__api_endpoint, func.lstrip(), urllib.urlencode(get))
+        url = "%s%s?%s" % (self._api_endpoint, func.lstrip(), urllib.urlencode(get))
         request = urllib2.Request(url)
         if _post:
             request.data = json.dumps(_post)
 
         try:
-            response = self.__opener.open(request)
+            response = self._opener.open(request)
             body = response.read()
         except urllib2.URLError, e:
             raise errors.HTTPError(e, e.reason)
@@ -171,8 +171,8 @@ class ApiClient(object):
         if self.debug:
             result.body = body
 
-        self.__calls.append(result)
-        self.__calls_time += result.time
+        self._calls.append(result)
+        self._calls_time += result.time
 
         result.process(body)
 
@@ -185,7 +185,7 @@ class Service(object):
     """
 
     def __init__(self, client):
-        self.__client = client
+        self._client = client
 
     def _callapi(self, func, get=None, post=None):
-        return self.__client.call(func, get, post)
+        return self._client.call(func, get, post)
